#!/store/bin/wish
####################################################################
#
#        File: XTcldump.tcl
# Description: Provide a GUI frontend for tcpdump
#    Language: Tcl/Tk
#      Author: Sveinar Rasmussen (sveinarr@stud.cs.uit.no)
#        Date: Wed May 6 10:22:04 METDST 1998
#     Version: 1.0.2
#
####################################################################

set PROGRAM_PATH /store/sbin/tcpdump

###################################
# My global variables are below
###################################
global selectedButton; 
global widget;

###################################
# My proc's are below
###################################
proc init { flag } {
    global flag1 flag2 flag3 flag3 flag4 flag5 flag6 flag7 flag8 flag9
    global entry1 entry2 entry3 entry4 entry5 entry6
    global expression PIDtcpdump PROGRAM_PATH

    set PIDtcpdump ""
    if {[file exists xtcpdump.rc] && $flag=="normal"} {
	set f [open xtcpdump.rc r]
	gets $f idControl
	if {$idControl!="XTcpdump config - rev A"} {
	    puts "Panic! Error in config file. Aborted."
	    exit
	}
	gets $f flag1
	gets $f flag2
	gets $f flag3
	gets $f flag4
	gets $f flag5
	gets $f flag6
	gets $f flag7
	gets $f flag8
	gets $f flag9
	gets $f entry1
	gets $f entry2
	gets $f entry3
	gets $f entry4
	gets $f entry5
	gets $f entry6
	gets $f expression
	close $f
    } else {
	set flag1 0
	set flag2 0
	set flag3 0
	set flag4 0
	set flag5 0
	set flag6 0
	set flag7 0
	set flag8 0
	set flag9 0
	set entry1 ""
	set entry2 ""
	set entry3 ""
	set entry4 ""
	set entry5 ""
	set entry6 $PROGRAM_PATH
	if {$flag=="normal"} {
	    set expression ""
	}
    }
}

proc Window {args} {
    global Tcl
    set cmd [lindex $args 0]
    set name [lindex $args 1]
    set newname [lindex $args 2]
    set rest [lrange $args 3 end]
    if {$name == "" || $cmd == ""} {return}
    if {$newname == ""} {
        set newname $name
    }
    set exists [winfo exists $newname]
    switch $cmd {
        show {
            if {$exists == "1" && $name != "."} {wm deiconify $name; return}
            if {[info procs TclWindow(pre)$name] != ""} {
                eval "TclWindow(pre)$name $newname $rest"
            }
            if {[info procs TclWindow$name] != ""} {
                eval "TclWindow$name $newname $rest"
            }
            if {[info procs TclWindow(post)$name] != ""} {
                eval "TclWindow(post)$name $newname $rest"
            }
        }
        hide    { if $exists {wm withdraw $newname; return} }
        iconify { if $exists {wm iconify $newname; return} }
        destroy { if $exists {destroy $newname; return} }
    }
}

###################################
# Help system
###################################
proc do_help {helpText id} {
    set base ".help1$id"
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }
    toplevel $base -class Toplevel \
        -background #aaaaaaaaaaaa 
    wm focusmodel $base passive
    wm geometry $base 569x320+380+140
    wm maxsize $base 1200 950
    wm minsize $base 569 150
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm deiconify $base
    wm title $base "$id help - XTcpdump"

    text $base.text -relief raised -bd 2 -yscrollcommand\
          "$base.scroll set" -width 1024 -height 1200
    $base.text insert end $helpText
    scrollbar $base.scroll -command "$base.text yview"
    button $base.ok -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 11 -pady 4 -text "I see!" -command "wm withdraw $base"
    pack $base.ok -side bottom -pady 2m
    pack $base.scroll -side right -fill y
    pack $base.text -side left
}

###################################
# Events
###################################
proc but_start {} {
    global flag1 flag2 flag3 flag3 flag4 flag5 flag6 flag7 flag8 flag9
    global entry1 entry2 entry3 entry4 entry5 entry6
    global expression PIDtcpdump
    if {$PIDtcpdump!=""} {
	but_stop
    }

    set args ""
    if {$flag1=="1"} {
	append args "-e "
    }
    if {$flag2=="1"} {
	append args "-f "
    }
    if {$flag3=="1"} {
	append args "-l "
    }
    if {$flag4=="1"} {
	append args "-n "
    }
    if {$flag5=="1"} {
	append args "-N "
    }
    if {$flag6=="1"} {
	append args "-p "
    }
    if {$flag7=="1"} {
	append args "-v "
    }
    if {$flag8=="1"} {
	append args "-vv "
    }
    if {$entry1!=""} {
	append args "-c $entry1 "
    }
    if {$entry2!=""} {
        append args "-s $entry2 "
    }
    if {$entry3!=""} {
	append args "-i $entry3 "
    }
    if {$entry4!=""} {
	append args "-T $entry4 "
    }
    if {$entry5!=""} {
	append args "-w $entry5 "
    }

    set fScript [open .xtcpscr.tmp w]
    puts $fScript "#!/bin/sh\nexec $entry6 $args $expression"
    close $fScript
    exec chmod 700 .xtcpscr.tmp

    puts "\n--------\[Session started [clock format [clock seconds]]\]--------\n"
    if {$flag9=="0"} {
	set PIDtcpdump [exec ./.xtcpscr.tmp &]
    } else {
	set PIDtcpdump [exec >& XTcpdump.log ./.xtcpscr.tmp &]
	puts "All output is redirected to XTcpdump.log file."
    }
#    exec rm .xtcpscr.tmp
}

proc but_stop {} {
    global PIDtcpdump
    catch {exec kill $PIDtcpdump}
    if {$PIDtcpdump!=""} {
	puts "\n---------\[Session ended [clock format [clock seconds]]\]---------"
    }
    set PIDtcpdump ""
    exec rm .xtcpscr.tmp
}

proc but_saveSetup {} {
    global flag1 flag2 flag3 flag3 flag4 flag5 flag6 flag7 flag8 flag9
    global entry1 entry2 entry3 entry4 entry5 entry6
    global expression 

    set f [open xtcpdump.rc w]
    puts $f "XTcpdump config - rev A"
    puts $f $flag1
    puts $f $flag2
    puts $f $flag3
    puts $f $flag4
    puts $f $flag5
    puts $f $flag6
    puts $f $flag7
    puts $f $flag8
    puts $f $flag9
    puts $f $entry1
    puts $f $entry2
    puts $f $entry3
    puts $f $entry4
    puts $f $entry5
    puts $f $entry6
    puts $f $expression
    close $f
}

proc but_options {} {
    Window show .option1
}
proc but_clearExpr {} {
    global expression
    set expression ""
}
proc but_exit {} {
    exit
}
proc but_cfgDefault {} {
    init "override"
}
proc but_cfgClose {} {
    wm withdraw .option1
}

proc but_about {} {
    set aboutText "\n\
\         __  _______              _                       \n\
\         \\ \\/ /_   _|__ _ __   __| |_   _ _ __ ___  _ __  \n\
\          \\  /  | |/ __| '_ \\ / _` | | | | '_ ` _ \\| '_ \\ \n\
\          /  \\  | | (__| |_) | (_| | |_| | | | | | | |_) |\n\
\         /_/\\_\\ |_|\\___| .__/ \\__,_|\\__,_|_| |_| |_| .__/ \n\
\                       |_|                         |_|    \n\
\n\
\                 - a flexible network monitor -\n\n\
\n\
\                 Copyright (c) 1997 CC Software\n\
\                      All rights reserved.\n\n\
\                Version: 1.0.2 (Wed May 6 1998)\n\
\                Author:  sveinarr@stud.cs.uit.no\n"

    set base .about1
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }
    toplevel $base -class Toplevel \
        -background #aaaaaaaaaaaa 
    wm focusmodel $base passive
    wm geometry $base 425x300+345+445
    wm maxsize $base 425 300
    wm minsize $base 425 300
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm deiconify $base
    wm title $base "About - XTcpdump"

    text $base.text -relief raised -bd 2 
    $base.text insert end $aboutText
    button $base.ok -background #aaaaaaaaaaaa \
    -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
    -padx 11 -pady 4 -text Wow! -command "wm withdraw $base"
    pack $base.ok -side bottom -pady 2m
    pack $base.text -side left
}
proc but_manpage {} {
    set f 0
    if { [catch {open xtcpdump.hlp r} f]} {
	puts "Install error: xtcpdump.hlp file couldn't be found."
	return
    }
    set manpage [read $f 10000000]
    close $f
    do_help $manpage "Man"
}

###################################
# GUI
###################################
proc TclWindow. {base} {
    if {$base == ""} {
        set base .
    }
    wm focusmodel $base passive
    wm geometry $base 1x1+0+0
    wm maxsize $base 1265 994
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm withdraw $base
    wm title $base "xtcpdump.tcl"
}

###################################
# GUI Main Window
###################################
proc TclWindow.main1 {base} {
    global expression

    if {$base == ""} {
        set base .main1
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }
    toplevel $base -class Toplevel -background #aaaaaaaaaaaa 
    wm focusmodel $base passive
    wm geometry $base 485x285+515+2
    wm maxsize $base 485 285
    wm minsize $base 485 285
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm deiconify $base
    wm title $base "XTcpdump (c) 1997 CC Software"
    message $base.mes19 \
        -aspect 1000 -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 5 -pady 2 -text {- Flexible network monitoring tool -} 
    canvas $base.can20 \
        -background #aaaaaaaaaaaa -borderwidth 2 -height 262 -relief ridge \
        -width 374 
    frame $base.fra21 \
        -background #aaaaaaaaaaaa -borderwidth 2 -height 75 -relief groove \
        -width 125 
    button $base.fra21.but23 \
        -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 11 -pady 4 -text Start! -command {but_start}
    label $base.fra21.lab24 \
        -background #aaaaaaaaaaaa -borderwidth 1 \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -relief raised -text label 
    button $base.fra21.but25 \
        -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 11 -pady 4 -text {Save setup} -command {but_saveSetup} 
    button $base.fra21.but26 \
        -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 11 -pady 4 -text Options... -command {but_options}
    button $base.fra21.but27 \
        -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 11 -pady 4 -text Help -command {but_helpMain} 
    button $base.fra21.but39 \
        -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 11 -pady 4 -text Stop! -command {but_stop} 
    label $base.lab28 \
        -background #aaaaaaaaaaaa -borderwidth 1 \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -relief raised -text { General } 
    label $base.lab29 \
        -background #aaaaaaaaaaaa -borderwidth 1 \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -relief raised -text label 
    frame $base.fra30 \
        -background #aaaaaaaaaaaa -borderwidth 2 -height 75 -relief groove \
        -width 125 
    entry $base.fra30.ent31 \
        -background #aaaaaaaaaaaa -textvariable expression \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* 
    label $base.fra30.lab32 \
        -background #aaaaaaaaaaaa -borderwidth 1 \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -relief raised -text label 
    button $base.fra30.but34 \
        -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 11 -pady 4 -text Clear -command {but_clearExpr}
    button $base.fra30.but35 \
        -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 11 -pady 4 -text Help -command {but_helpExpr} 
    button $base.fra30.but37 \
        -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 11 -pady 4 -text button 
    label $base.lab33 \
        -background #aaaaaaaaaaaa -borderwidth 1 \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -relief raised -text { Match expression } 
    button $base.but36 \
        -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 11 -pady 4 -text Close -command {but_exit} 
    button $base.but38 \
        -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 11 -pady 4 -text About -command {but_about}
    button $base.but39 \
        -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 11 -pady 4 -text "Man page" -command {but_manpage}
    place $base.mes19 \
        -x 5 -y 10 -width 475 -height 14 -anchor nw -bordermode ignore 
    place $base.fra21 \
        -x 10 -y 50 -width 465 -height 70 -anchor nw -bordermode ignore 
    place $base.fra21.but23 \
        -x 10 -y 10 -width 66 -height 49 -anchor nw -bordermode ignore 
    place $base.fra21.but25 \
        -x 275 -y 20 -anchor nw -bordermode ignore 
    place $base.fra21.but26 \
        -x 175 -y 20 -anchor nw -bordermode ignore 
    place $base.fra21.but27 \
        -x 395 -y 20 -anchor nw -bordermode ignore 
    place $base.fra21.but39 \
        -x 85 -y 10 -width 66 -height 49 -anchor nw -bordermode ignore 
    place $base.lab28 \
        -x 5 -y 35 -anchor nw -bordermode ignore 
    place $base.fra30 \
        -x 10 -y 145 -width 465 -height 90 -anchor nw -bordermode ignore 
    place $base.fra30.ent31 \
        -x 10 -y 45 -width 445 -height 30 -anchor nw -bordermode ignore 
    place $base.fra30.but34 \
        -x 15 -y 10 -anchor nw -bordermode ignore 
    place $base.fra30.but35 \
        -x 395 -y 10 -anchor nw -bordermode ignore 
    place $base.lab33 \
        -x 5 -y 130 -anchor nw -bordermode ignore 
    place $base.but36 \
        -x 405 -y 245 -anchor nw -bordermode ignore 
    place $base.but38 \
        -x 15 -y 245 -anchor nw -bordermode ignore 
    place $base.but39 \
        -x 197 -y 245 -anchor nw -bordermode ignore 
}

###################################
# GUI Option window
###################################
proc TclWindow.option1 {base} {
    global flag1 flag2 flag3 flag3 flag4 flag5 flag6 flag7 flag8 flag9
    global entry1 entry2 entry3 entry4 entry5 entry6

    if {$base == ""} {
        set base .option1
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }
    toplevel $base -class Toplevel \
        -background #aaaaaaaaaaaa 
    wm focusmodel $base passive
    wm geometry $base 489x563+20+2
    wm maxsize $base 1265 994
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm deiconify $base
    wm title $base "Options - XTcpdump"
    message $base.mes41 \
        -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 5 -pady 2 -text message 
    message $base.mes43 \
        -aspect 1000 -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 5 -pady 2 -text {- Various options for tcpdump -} 
    frame $base.fra44 \
        -background #aaaaaaaaaaaa -borderwidth 2 -height 95 -relief groove \
        -width 125 
    checkbutton $base.fra44.che45 \
        -anchor w -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -justify left -text {Print linklevel header                       } \
        -variable flag1 -width 50 
    checkbutton $base.fra44.che46 \
        -anchor w -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -justify left -text {Print number instead of symbolic address} \
        -variable flag2 -width 50 
    checkbutton $base.fra44.che47 \
        -anchor w -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -justify left -text {Make stdout line buffered} -variable flag3 \
        -width 50 
    checkbutton $base.fra44.che48 \
        -anchor w -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -text {Don't convert address to names} -variable flag4 -width 50 
    checkbutton $base.fra44.che49 \
        -anchor w -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -text {Don't print domain name} -variable flag5 -width 50 
    checkbutton $base.fra44.che50 \
        -anchor w -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -text {Don't use promiscuous mode} -variable flag6 -width 50 
    checkbutton $base.fra44.che51 \
        -anchor w -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -justify left -text {Give me more output  } -variable che51 -width 50 
    checkbutton $base.fra44.che52 \
        -anchor w -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -text {Give me more output} -variable flag7 -width 50 
    checkbutton $base.fra44.che53 \
        -anchor w -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -text {Give me even more output} -variable flag8 -width 50 
    checkbutton $base.fra44.che54 \
        -anchor w -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -text {Use Xtcpdump.log to save all output} -variable flag9 -width 50 
    label $base.lab56 \
        -background #aaaaaaaaaaaa -borderwidth 1 \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -relief raised -text { Flags } 
    frame $base.fra57 \
        -background #aaaaaaaaaaaa -borderwidth 2 -height 75 -relief groove \
        -width 125 
    entry $base.fra57.ent58 \
        -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -justify right -width 10 -textvariable entry1
    entry $base.fra57.ent59 \
        -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -justify right -width 10 -textvariable entry2
    entry $base.fra57.ent60 \
        -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -justify right -textvariable entry3
    label $base.fra57.lab61 \
        -background #aaaaaaaaaaaa -borderwidth 1 \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -relief raised -text label 
    entry $base.fra57.ent62 \
        -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -justify right -textvariable entry4
    entry $base.fra57.ent63 \
        -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -justify right -textvariable entry5
    entry $base.fra57.ent64 \
        -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -justify right -textvariable entry6
    message $base.fra57.mes64 \
        -anchor e -aspect 1000 -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 5 -pady 2 -text {Exit after receiving # packets} 
    message $base.fra57.mes69 \
        -anchor e -aspect 1300 -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 5 -pady 2 -text {Write the raw packets to file instead} 
    message $base.fra57.mes73 \
        -anchor e -aspect 1300 -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 5 -pady 2 -text {Path to tcpdump program} 
    message $base.fra57.mes70 \
        -anchor e -aspect 1200 -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 5 -pady 2 -text {Force packets selected specified by type} 
    message $base.fra57.mes71 \
        -anchor e -aspect 1000 -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 5 -pady 2 -text {Listen on interface} 
    message $base.fra57.mes72 \
        -anchor e -aspect 1000 -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 5 -pady 2 -text {Snap length of each packet} 
    label $base.lab73 \
        -background #aaaaaaaaaaaa -borderwidth 1 \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -relief raised -text { Input options } 
    button $base.but74 \
        -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 11 -pady 4 -text Close -command {but_cfgClose}
    button $base.but75 \
        -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 11 -pady 4 -text "Default" -command {but_cfgDefault}
    button $base.but20 \
        -background #aaaaaaaaaaaa \
        -font -misc-fixed-medium-r-semicondensed--13-100-100-100-*-60-iso8859-* \
        -padx 11 -pady 4 -text Help -command {but_cfgHelp}
    place $base.mes43 \
        -x 5 -y 10 -width 475 -height 14 -anchor nw -bordermode ignore 
    place $base.fra44 \
        -x 15 -y 45 -width 455 -height 245 -anchor nw -bordermode ignore 
    place $base.fra44.che45 \
        -x 60 -y 10 -anchor nw -bordermode ignore 
    place $base.fra44.che46 \
        -x 60 -y 35 -anchor nw -bordermode ignore 
    place $base.fra44.che47 \
        -x 60 -y 60 -anchor nw -bordermode ignore 
    place $base.fra44.che48 \
        -x 60 -y 85 -anchor nw -bordermode ignore 
    place $base.fra44.che49 \
        -x 60 -y 110 -anchor nw -bordermode ignore 
    place $base.fra44.che50 \
        -x 60 -y 135 -anchor nw -bordermode ignore 
    place $base.fra44.che52 \
        -x 60 -y 160 -anchor nw -bordermode ignore 
    place $base.fra44.che53 \
        -x 60 -y 185 -anchor nw -bordermode ignore 
    place $base.fra44.che54 \
        -x 60 -y 210 -anchor nw -bordermode ignore 
    place $base.lab56 \
        -x 10 -y 30 -width 39 -height 17 -anchor nw -bordermode ignore 
    place $base.fra57 \
        -x 15 -y 315 -width 455 -height 200 -anchor nw -bordermode ignore 
    place $base.fra57.ent58 \
        -x 370 -y 10 -height 23 -anchor nw -bordermode ignore 
    place $base.fra57.ent59 \
        -x 370 -y 40 -anchor nw -bordermode ignore 
    place $base.fra57.ent60 \
        -x 310 -y 70 -anchor nw -bordermode ignore 
    place $base.fra57.ent62 \
        -x 310 -y 100 -anchor nw -bordermode ignore 
    place $base.fra57.ent63 \
        -x 310 -y 130 -anchor nw -bordermode ignore 
    place $base.fra57.ent64 \
        -x 310 -y 160 -anchor nw -bordermode ignore 
    place $base.fra57.mes64 \
        -x 10 -y 10 -width 280 -height 19 -anchor nw -bordermode ignore 
    place $base.fra57.mes69 \
        -x 10 -y 130 -width 280 -height 19 -anchor nw -bordermode ignore 
    place $base.fra57.mes70 \
        -x 10 -y 100 -width 280 -height 19 -anchor nw -bordermode ignore 
    place $base.fra57.mes71 \
        -x 10 -y 70 -width 280 -height 19 -anchor nw -bordermode ignore 
    place $base.fra57.mes72 \
        -x 10 -y 40 -width 280 -height 19 -anchor nw -bordermode ignore 
    place $base.fra57.mes73 \
        -x 10 -y 160 -width 280 -height 19 -anchor nw -bordermode ignore 
    place $base.lab73 \
        -x 10 -y 300 -anchor nw -bordermode ignore 
    place $base.but74 \
        -x 405 -y 520 -anchor nw -bordermode ignore 
    place $base.but75 \
        -x 20 -y 520 -anchor nw -bordermode ignore 
    place $base.but20 \
        -x 215 -y 520 -anchor nw -bordermode ignore 
}
    
###################################
# Main proc
###################################
proc main {argc argv} {
    init "normal"
    Window show .
    Window show .main1
}

main $argc $argv


###################################
# Docs are below this line
###################################
proc but_helpMain {} {
    do_help "\n\
O V E R V I E W\n\
\n\
tcpdump is a network monitoring program capable of observing all traffic on\n\
a local network. As such, it can be used to provide raw trace data to a \n\
performance monitoring tool. \n\
\n\
tcpdump monitors the network at the packet level. Each packet is typically \n\
displayed as a combination of a line summarizing the packet contents, and \n\
then the packet contents themselves. The summary line, which includes a \n\
timestamp indicating when the packet was observed on the network, contains \n\
some of the more important information about the packet. For a UDP \n\
connection, for example, the summary information includes such things as \n\
the name of the host that sent the packet and the port from which it was \n\
sent. It also includes the name of the host and port for which the packet\n\
is destined. For a NFS connection, the summary information includes the \n\
source and destination of the packet, along with an indication of whether \n\
a read or write operation was requested. It may also include the amount of \n\
data being sent in the transfer, and the total amount of data sent for the \n\
request to which this response belongs. \n\
\n\
XTcpdump provides a intuitive graphical user interface frontend to tcpdump.\n\
This simplifies the usage and makes it easier for people to get started\n\
using tcpdump as a flexible network monitoring tool.\n\
\n\
\n\
U S A G E\n\
\n\
There are four buttons residing in the frame where you pressed the help\n\
button. All of them are explained below:\n\
\n\
Start!         activates tcpdump to start monitoring according to your\n\
\               selection of options and commands. Its output will be\n\
\               found in the standard output window where XTcpdump was\n\
\               launched from.\n\
\n\
Stop!          deactivates tcpdump if it is running.\n\
\n\
Options...     a whole set of options are presented to you once you \n\
\               press this button. I recommend that you push the help\n\
\               button found in the option window.\n\
\n\
Save setup     all your settings are stored to disk.\n\
\n\
\n\
After setting or/and saving the setup, write in a suitable matching \n\
expression according to the help found in the expression frame, press\n\
Start! to get monitoring...\n" "Main"
}
proc but_helpExpr {} {
    do_help "\n\
\                      M A T C H    E X P R E S S I O N\n\
\n\
\                                   - - -\n\
\n\
\n\
\              Clear the expression by using the  \"Clear\"  button.\n\
\n\
\              Write   your   expression  in  the  field.   If  no\n\
\              expression is given, all packets on the net will be\n\
\              dumped.   Otherwise, only packets for which expres-\n\
\              sion is `true' will be dumped.\n\
\n\
\              The expression consists of one or more  primitives.\n\
\              Primitives  usually  consist of an id (name or num-\n\
\              ber) preceded by one or more qualifiers.  There are\n\
\              three different kinds of qualifier:\n\
\n\
\              type   qualifiers  say  what  kind  of thing the id\n\
\                     name or number refers  to.   Possible  types\n\
\                     are  host,  net and port.  E.g., `host foo',\n\
\                     `net 128.3', `port 20'.  If there is no type\n\
\                     qualifier, host is assumed.\n\
\n\
\              dir    qualifiers  specify  a  particular  transfer\n\
\                     direction  to  and/or  from  id.    Possible\n\
\                     directions  are src, dst, src or dst and src\n\
\                     and dst.  E.g., `src foo', `dst net  128.3',\n\
\                     `src  or dst port ftp-data'.  If there is no\n\
\                     dir qualifier, src or dst is  assumed.   For\n\
\                     `null' link layers (i.e. point to point pro-\n\
\                     tocols such as slip) the  inbound  and  out-\n\
\                     bound  qualifiers  can  be used to specify a\n\
\                     desired direction.\n\
\n\
\              proto  qualifiers restrict the match to a  particu-\n\
\                     lar  protocol.   Possible protos are: ether,\n\
\                     fddi,  ip,  arp,  rarp,  decnet,  lat,  sca,\n\
\                     moprc, mopdl, tcp and udp.  E.g., `ether src\n\
\                     foo', `arp net 128.3', `tcp  port  21'.   If\n\
\                     there  is  no proto qualifier, all protocols\n\
\                     consistent with the type are assumed.  E.g.,\n\
\                     `src  foo'  means  `(ip  or arp or rarp) src\n\
\                     foo' (except the latter is  not  legal  syn-\n\
\                     tax),  `net  bar' means `(ip or arp or rarp)\n\
\                     net bar' and `port 53' means `(tcp  or  udp)\n\
\                     port 53'.\n\
\n\
\              \[`fddi'  is  actually  an  alias  for  `ether'; the\n\
\              parser treats them  identically  as  meaning  ``the\n\
\              data  link  level  used  on  the  specified network\n\
\              interface.''  FDDI  headers  contain  Ethernet-like\n\
\              source and destination addresses, and often contain\n\
\              Ethernet-like packet types, so you  can  filter  on\n\
\              these FDDI fields just as with the analogous Ether-\n\
\              net  fields.   FDDI  headers  also  contain   other\n\
\              fields,  but  you  cannot name them explicitly in a\n\
\              filter expression.\]\n\
\n\
\              In addition to the above, there  are  some  special\n\
\              `primitive' keywords that don't follow the pattern:\n\
\              gateway, broadcast, less,  greater  and  arithmetic\n\
\              expressions.  All of these are described below.\n\
\n\
\              More  complex  filter  expressions  are built up by\n\
\              using the words and, or and not to  combine  primi-\n\
\              tives.   E.g.,  `host  foo and not port ftp and not\n\
\              port ftp-data'.  To save typing,  identical  quali-\n\
\              fier lists can be omitted.  E.g., `tcp dst port ftp\n\
\              or ftp-data or domain' is exactly the same as  `tcp\n\
\              dst  port  ftp  or tcp dst port ftp-data or tcp dst\n\
\              port domain'.\n\
\n\
\              Allowable primitives are:\n\
\n\
\              dst host 'host'\n\
\                     True if the  IP  destination  field  of  the\n\
\                     packet  is  host,  which  may  be  either an\n\
\                     address or a name.\n\
\n\
\              src host 'host'\n\
\                     True if the IP source field of the packet is\n\
\                     host.\n\
\n\
\              host 'host'\n\
\                     True  if either the IP source or destination\n\
\                     of the packet is host.   Any  of  the  above\n\
\                     host  expressions  can be prepended with the\n\
\                     keywords, ip, arp, or rarp as in:\n\
\                         ip host host\n\
\                    which is equivalent to:\n\
\                          ether proto \ip and host host\n\
\n\
\                     If  host  is  a  name   with   multiple   IP\n\
\                     addresses,  each address will be checked for\n\
\                     a match.\n\
\n\
\              ether dst 'ehost'\n\
\                     True if the ethernet destination address  is\n\
\                     ehost.   Ehost  may  be  either  a name from\n\
\                     /etc/ethers or a number (see ethers(3N)  for\n\
\                     numeric format).\n\
\n\
\              ether src 'ehost'\n\
\                     True  if  the  ethernet  source  address  is\n\
\                     ehost.\n\
\n\
\              ether host 'ehost'\n\
\                     True if either the ethernet source or desti-\n\
\                     nation address is ehost.\n\
\n\
\              gateway 'host'\n\
\                     True  if  the packet used host as a gateway.\n\
\                     I.e., the  ethernet  source  or  destination\n\
\                     address  was  host but neither the IP source\n\
\                     nor the IP destination was host.  Host  must\n\
\                     be   a  name  and  must  be  found  in  both\n\
\                     /etc/hosts and /etc/ethers.  (An  equivalent\n\
\                     expression is\n\
\                          ether host ehost and not host host\n\
\                     which  can be used with either names or num-\n\
\                     bers for host / ehost.)\n\
\n\
\              dst net 'net'\n\
\                     True if the IP destination  address  of  the\n\
\                     packet  has a network number of net. Net may\n\
\                     be either a name  from  /etc/networks  or  a\n\
\                     network    number   (see   networks(4)   for\n\
\                     details).\n\
\n\
\              src net 'net'\n\
\                     True if the IP source address of the  packet\n\
\                     has a network number of net.\n\
\n\
\              net 'net'\n\
\                     True  if either the IP source or destination\n\
\                     address of the packet has a  network  number\n\
\                     of net.\n\
\n\
\              net 'net' mask 'mask'\n\
\                     True  if the IP address matches net with the\n\
\                     specific netmask.  May be qualified with src\n\
\                     or dst.\n\
\n\
\              net 'net'/'len'\n\
\                     True if the IP address matches net a netmask\n\
\                     len bits wide.  May be qualified with src or\n\
\                     dst.\n\
\n\
\              dst port 'port'\n\
\                     True  if  the packet is ip/tcp or ip/udp and\n\
\                     has a destination port value of  port.   The\n\
\                     port  can  be  a  number  or  a name used in\n\
\                     /etc/services (see tcp(4P) and udp(4P)).  If\n\
\                     a  name  is  used,  both the port number and\n\
\                     protocol  are  checked.   If  a  number   or\n\
\                     ambiguous name is used, only the port number\n\
\                     is checked (e.g., dst port  513  will  print\n\
\                     both  tcp/login traffic and udp/who traffic,\n\
\                     and port domain will print  both  tcp/domain\n\
\                     and udp/domain traffic).\n\
\n\
\              src port 'port'\n\
\                     True  if  the packet has a source port value\n\
\                     of port.\n\
\n\
\              port 'port'\n\
\                     True if either  the  source  or  destination\n\
\                     port  of  the  packet  is  port.  Any of the\n\
\                     above port expressions can be prepended with\n\
\                     the keywords, tcp or udp, as in:\n\
\                          tcp src port port\n\
\                     which  matches only tcp packets whose source\n\
\                     port is port.\n\
\n\
\              less 'length'\n\
\                     True if the packet has a length less than or\n\
\                     equal to length.  This is equivalent to:\n\
\                          len <= length.\n\
\n\
\              greater 'length'\n\
\                     True if the packet has a length greater than\n\
\                     or equal to length.  This is equivalent to:\n\
\                          len >= length.\n\
\n\
\              ip proto 'protocol'\n\
\                     True if the packet  is  an  ip  packet  (see\n\
\                     ip(4P)) of protocol type protocol.  Protocol\n\
\                     can be a number or one of  the  names  icmp,\n\
\                     igrp,  udp, nd, or tcp.  Note that the iden-\n\
\                     tifiers tcp, udp, and icmp are also keywords\n\
\                     and must be escaped via backslash (\), which\n\
\                     is \\ in the C-shell.\n\
\n\
\              ether broadcast\n\
\                     True if the packet is an ethernet  broadcast\n\
\                     packet.  The ether keyword is optional.\n\
\n\
\              ip broadcast\n\
\                     True  if  the  packet  is  an  IP  broadcast\n\
\                     packet.  It checks for both  the  all-zeroes\n\
\                     and   all-ones  broadcast  conventions,  and\n\
\                     looks up the local subnet mask.\n\
\n\
\              ether multicast\n\
\                     True if the packet is an ethernet  multicast\n\
\                     packet.   The  ether  keyword  is  optional.\n\
\                     This is shorthand for `ether\[0\] & 1 != 0'.\n\
\n\
\              ip multicast\n\
\                     True  if  the  packet  is  an  IP  multicast\n\
\                     packet.\n\
\n\
\              ether proto 'protocol'\n\
\                     True  if  the packet is of ether type proto-\n\
\                     col.  Protocol can be a  number  or  a  name\n\
\                     like  ip,  arp, or rarp.  Note these identi-\n\
\                     fiers are also keywords and must be  escaped\n\
\                     via  backslash  (\).   \[In  the case of FDDI\n\
\                     (e.g., `fddi protocol  arp'),  the  protocol\n\
\                     identification  comes from the 802.2 Logical\n\
\                     Link Control (LLC) header, which is  usually\n\
\                     layered  on top of the FDDI header.  Tcpdump\n\
\                     assumes,  when  filtering  on  the  protocol\n\
\                     identifier, that all FDDI packets include an\n\
\                     LLC header, and that the LLC  header  is  in\n\
\                     so-called SNAP format.\]\n\
\n\
\              decnet src 'host'\n\
\                     True  if  the DECNET source address is host,\n\
\                     which  may  be  an  address  of   the   form\n\
\                     ``10.123'',  or a DECNET host name.  \[DECNET\n\
\                     host  name  support  is  only  available  on\n\
\                     Ultrix  systems  that  are configured to run\n\
\                     DECNET.\]\n\
\n\
\              decnet dst 'host'\n\
\                     True if the DECNET  destination  address  is\n\
\                     host.\n\
\n\
\              decnet host 'host'\n\
\                     True if either the DECNET source or destina-\n\
\                     tion address is host.\n\
\n\
\              ip, arp, rarp, decnet\n\
\                     Abbreviations for:\n\
\                          ether proto p\n\
\                     where p is one of the above protocols.\n\
\n\
\              lat, moprc, mopdl\n\
\                     Abbreviations for:\n\
\                          ether proto p\n\
\                     where p is one of the above protocols.  Note\n\
\                     that  tcpdump does not currently know how to\n\
\                     parse these protocols.\n\
\n\
\              tcp, udp, icmp\n\
\                     Abbreviations for:\n\
\                          ip proto p\n\
\                     where p is one of the above protocols.\n\
\n\
\              expr relop 'expr'\n\
\                     True if the relation holds, where  relop  is\n\
\                     one  of  >, <, >=, <=, =, !=, and expr is an\n\
\                     arithmetic expression  composed  of  integer\n\
\                     constants  (expressed in standard C syntax),\n\
\                     the normal binary operators \[+, -, *, /,  &,\n\
\                     |\],  a  length  operator, and special packet\n\
\                     data accessors.  To access data  inside  the\n\
\                     packet, use the following syntax:\n\
\                          proto \[ expr : size \]\n\
\                     Proto  is one of ether, fddi, ip, arp, rarp,\n\
\                     tcp, udp, or icmp, and indicates the  proto-\n\
\                     col layer for the index operation.  The byte\n\
\                     offset, relative to the  indicated  protocol\n\
\                     layer,  is  given by expr.  Size is optional\n\
\                     and indicates the number  of  bytes  in  the\n\
\                     field  of  interest;  it  can be either one,\n\
\                     two, or four,  and  defaults  to  one.   The\n\
\                     length  operator,  indicated  by the keyword\n\
\                     len, gives the length of the packet.\n\
\n\
\                     For example, `ether\[0\] & 1 != 0' catches all\n\
\                     multicast  traffic.  The expression `ip\[0\] &\n\
\                     0xf  !=  5'  catches  all  IP  packets  with\n\
\                     options.  The expression `ip\[6:2\] & 0x1fff =\n\
\                     0' catches only unfragmented  datagrams  and\n\
\                     frag  zero  of  fragmented  datagrams.  This\n\
\                     check is implicitly applied to the  tcp  and\n\
\                     udp  index operations.  For instance, tcp\[0\]\n\
\                     always means  the  first  byte  of  the  TCP\n\
\                     header, and never means the first byte of an\n\
\                     intervening fragment.\n\
\n\
\              Primitives may be combined using:\n\
\n\
\                     A  parenthesized  group  of  primitives  and\n\
\                     operators  (parentheses  are  special to the\n\
\                     Shell and must be escaped).\n\
\n\
\                     Negation (`!' or `not').\n\
\n\
\                     Concatenation (`&&' or `and').\n\
\n\
\                     Alternation (`||' or `or').\n\
\n\
\              Negation has highest precedence.   Alternation  and\n\
\              concatenation  have  equal precedence and associate\n\
\              left to right.  Note that explicit and tokens,  not\n\
\              juxtaposition,  are now required for concatenation.\n\
\n\
\              If an identifier is given without  a  keyword,  the\n\
\              most recent keyword is assumed.  For example,\n\
\                   not host vs and ace\n\
\              is short for\n\
\                   not host vs and host ace\n\
\              which should not be confused with\n\
\                   not ( host vs or ace )\n\
\n\
\              Expression  arguments  can  be passed to tcpdump as\n\
\              either a single argument or as multiple  arguments,\n\
\              whichever  is  more  convenient.  Generally, if the\n\
\              expression contains  Shell  metacharacters,  it  is\n\
\              easier  to  pass  it  as a single, quoted argument.\n\
\              Multiple arguments  are  concatenated  with  spaces\n\
\              before being parsed.\n" "Expression"
}
proc but_cfgHelp {} {
    do_help "\n\
\                             O P T I O N S\n\
\n\
\                                 - - -\n\
F L A G S\n\
\n\
\n\
* Print linklevel header          prints the header on each dump line.\n\
\n\
* Print number instead of         print 'foreign' adresses numerically\n\
\  symbolic adress                 rather than symbolically. Sun's yp\n\
\                                  server? use it!\n\
\n\
* Make stdout line buffered       make stdout line buffered. Useful if\n\
\                                  you want to see the data while \n\
\                                  capturing it.\n\
\n\
* Don't convert address to        doesn't convert addresses (i.e. host\n\
\  names                           addresses, port numbers, etc.) to \n\
\                                  names.\n\
\n\
* Don't print domain name         doesn't print domain name qualification\n\
\                                  of host names. 'slibo.cc.uit.no' will be\n\
\                                  'slibo', eg.\n\
\n\
* Don't use promiscuous mode      doesn't put interface into promiscuous\n\
\                                  mode. Note that the interface might be\n\
\                                  in promiscuous mode for some other reason.\n\
\n\              
 * Give me more output             slightly more verbose output.\n\
\n\
* Give me even more output        a lot of output.\n\
\n\
* Use Xtcpdump.log to save        saves all the output from the tcpdump\n\
\  all output                      program onto disk. Check the file\n\
\                                  Xtcpdump.log afterwards.\n\
\n\
\                                 - - -\n\
\n\
I N P U T   O P T I O N S\n\
\n\
\n\
* Exit after                      will exit tcpdump after receiving a \n\
\  receiving # packets             given number of packets.\n\
\n\
* Snap length of                  snarf a given number of bytes of data\n\
\  each packet                     from each packet rather than the default\n\
\                                  68 bytes.\n\
\n\
* Listen on interface             listen on interface. If unspecified, \n\
\                                  tcpdump searches the system interface\n\
\                                  list for the lowest numbered, configured\n\
\                                  up interface (excluding loopback of course\n\
\                                  :).\n\
\n\
* Force packets selected          packets selected by \"expression\" are of \n\
\  specified by type               this type. rpc (Remote Procedure Call), \n\
\                                  rtp (Real-Time Applications protocol), \n\
\                                  rtcp (Real-Time Applications control\n\
\                                  protocol), vat (Visual Audio Tool) and\n\
\                                  wb (distributed White Board).\n\
\n\
* Write the raw packets           write everything to disk instead of\n\
\  to file instead                 parsing it. Really \"dumps\" it all on \n\
\                                  disk using a lot of disk space.\n\
\n\
* Path to tcpdump                 the path to the necessary program\n\
\  program                         called tcpdump on your system.\n\
\n\
\                                 - - -\n\
\n\
Tip! Hitting the \"Default\" button will bring back factory settings.\n" \
                                                       "Configuration"
}
